***********
Basic Usage
***********

Installation
============
Install ``macromol_voxelize`` using ``pip``::

    $ pip install macromol_voxelize

- Requires python≥3.8
- Adheres to `semantic versioning`_.

.. _`semantic versioning`: https://semver.org/
